#
# spec file for package xmlsec1
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global libname    libxmlsec1-1
%global libopenssl libxmlsec1-openssl1
%global libgcrypt  libxmlsec1-gcrypt1
%global libgnutls  libxmlsec1-gnutls1
%global libnss     libxmlsec1-nss1
Name:           xmlsec1
Version:        1.2.23
Release:        4.1
Summary:        Library providing support for "XML Signature" and "XML Encryption" standards
License:        MIT
Group:          Productivity/Security
Url:            http://www.aleksey.com/xmlsec/
Source0:        http://www.aleksey.com/xmlsec/download/xmlsec1-%{version}.tar.gz
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(nspr)
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(openssl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
XML Security Library is a C library based on LibXML2  and OpenSSL.
The library was created with a goal to support major XML security
standards "XML Digital Signature" and "XML Encryption".

%package -n %{libname}
Summary:        Library providing support for "XML Signature" and "XML Encryption" standards
Group:          System/Libraries

%description -n %{libname}
XML Security Library is a C library based on LibXML2  and OpenSSL.
The library was created with a goal to support major XML security
standards "XML Digital Signature" and "XML Encryption".

%package -n %{libgcrypt}
Summary:        GCrypt crypto plugin for XML Security Library
Group:          System/Libraries

%description -n %{libgcrypt}
GCrypt plugin for XML Security Library provides GCrypt based crypto services
for the xmlsec library.

%package -n %{libgnutls}
Summary:        GNUTls crypto plugin for XML Security Library
Group:          System/Libraries

%description -n %{libgnutls}
GNUTls plugin for XML Security Library provides GNUTls based crypto services
for the xmlsec library.

%package -n %{libnss}
Summary:        NSS crypto plugin for XML Security Library
Group:          System/Libraries

%description -n %{libnss}
NSS plugin for XML Security Library provides NSS based crypto services
for the xmlsec library.

%package -n %{libopenssl}
Summary:        OpenSSL crypto plugin for XML Security Library
Group:          System/Libraries

%description -n %{libopenssl}
OpenSSL plugin for XML Security Library provides OpenSSL based crypto services
for the xmlsec library.

%package devel
Summary:        Libraries, includes for XML Signatures/Encryption
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libxml2-devel >= 2.6.0
Requires:       libxslt-devel >= 1.1.0
Requires:       openssl-devel >= 0.9.6
Requires:       zlib-devel

%description devel
Libraries, includes, etc. you can use to develop applications with XML Digital
Signatures and XML Encryption support.

%package openssl-devel
Summary:        OpenSSL crypto plugin for XML Security Library
Group:          Development/Libraries/C and C++
Requires:       %{libopenssl} = %{version}
Requires:       %{name}-devel = %{version}

%description openssl-devel
Libraries, includes, etc. for developing XML Security applications with OpenSSL

%package gcrypt-devel
Summary:        GCrypt crypto plugin for XML Security Library
Group:          Development/Libraries/C and C++
Requires:       %{libgcrypt} = %{version}
Requires:       %{name}-devel = %{version}

%description gcrypt-devel
Libraries, includes, etc. for developing XML Security applications with GCrypt.

%package gnutls-devel
Summary:        GNUTls crypto plugin for XML Security Library
Group:          Development/Libraries/C and C++
Requires:       %{libgnutls} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       %{name}-openssl-devel = %{version}
Requires:       gnutls-devel >= 1.0.20
Requires:       libgcrypt-devel >= 1.2.0

%description gnutls-devel
Libraries, includes, etc. for developing XML Security applications with GNUTls.

%package nss-devel
Summary:        NSS crypto plugin for XML Security Library
Group:          Development/Libraries/C and C++
Requires:       %{libnss} = %{version}
Requires:       %{name}-devel = %{version}
Requires:       mozilla-nspr-devel
Requires:       mozilla-nss-devel >= 3.2

%description nss-devel
Libraries, includes, etc. for developing XML Security applications with NSS.

%prep
%setup -q

%build
%configure \
    --disable-static \
    --disable-silent-rules
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

# move installed docs to include them in -devel package via %%doc magic
rm -rf __tmp_doc ; mkdir __tmp_doc
mv %{buildroot}%{_datadir}/doc/xmlsec1/* __tmp_doc
rmdir %{buildroot}%{_datadir}/doc/xmlsec1

%check
make %{?_smp_mflags} check check-keys check-dsig check-enc

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%post -n %{libgcrypt} -p /sbin/ldconfig
%postun -n %{libgcrypt} -p /sbin/ldconfig
%post -n %{libgnutls} -p /sbin/ldconfig
%postun -n %{libgnutls} -p /sbin/ldconfig
%post -n %{libnss} -p /sbin/ldconfig
%postun -n %{libnss} -p /sbin/ldconfig
%post -n %{libopenssl} -p /sbin/ldconfig
%postun -n %{libopenssl} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING ChangeLog
%{_mandir}/man1/xmlsec1.1*
%{_bindir}/xmlsec1

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxmlsec1.so.*

%files -n %{libgcrypt}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxmlsec1-gcrypt.so.*
%{_libdir}/libxmlsec1-gcrypt.so

%files -n %{libgnutls}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxmlsec1-gnutls.so.*
%{_libdir}/libxmlsec1-gnutls.so

%files -n %{libnss}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxmlsec1-nss.so.*
%{_libdir}/libxmlsec1-nss.so

%files -n %{libopenssl}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxmlsec1-openssl.so.*
%{_libdir}/libxmlsec1-openssl.so

%files devel
%defattr(-,root,root,-)
%doc COPYING AUTHORS ChangeLog NEWS
%doc HACKING __tmp_doc/*
%{_bindir}/xmlsec1-config
%dir %{_includedir}/xmlsec1
%dir %{_includedir}/xmlsec1/xmlsec
%dir %{_includedir}/xmlsec1/xmlsec/private
%{_includedir}/xmlsec1/xmlsec/*.h
%{_includedir}/xmlsec1/xmlsec/private/*.h
%{_libdir}/libxmlsec1.so
%{_libdir}/pkgconfig/xmlsec1.pc
%{_libdir}/xmlsec1Conf.sh
%{_datadir}/aclocal/xmlsec1.m4
%{_mandir}/man1/xmlsec1-config.1*

%files openssl-devel
%defattr(-,root,root,-)
%{_includedir}/xmlsec1/xmlsec/openssl/
%{_libdir}/pkgconfig/xmlsec1-openssl.pc

%files gcrypt-devel
%defattr(-,root,root,-)
%{_includedir}/xmlsec1/xmlsec/gcrypt/
%{_libdir}/pkgconfig/xmlsec1-gcrypt.pc

%files gnutls-devel
%defattr(-,root,root,-)
%{_includedir}/xmlsec1/xmlsec/gnutls/
%{_libdir}/pkgconfig/xmlsec1-gnutls.pc

%files nss-devel
%defattr(-,root,root,-)
%{_includedir}/xmlsec1/xmlsec/nss/
%{_libdir}/pkgconfig/xmlsec1-nss.pc

%changelog
* Thu Mar 23 2017 pmonrealgonzalez@suse.com
- Fixed dependencies with libraries (bsc#1012246):
  * libxmlsec1-openssl.so
  * libxmlsec1-gcrypt.so
  * libxmlsec1-gnutls.so
  * libxmlsec1-nss.so
* Mon Nov 28 2016 tchvatal@suse.com
- Version update to 1.2.23:
  * Full support for OpenSSL 1.1.0
  * Several other small fixes
* Wed May 25 2016 tchvatal@suse.com
- Version update to 1.2.22 (fate#320861):
  * see the ChangeLog for most detailed output
  * openssl 1.1 support
  * Few features from libreoffice for integrated
  * Run the testsuite
* Thu Sep  3 2015 astieger@suse.com
- update to 1.2.20:
  * fix a number of miscellaneous bugs
  * update expired or soon-to-be-expired certificates in test suite
* Tue Jan  7 2014 mvyskocil@suse.com
- Initial packaging of xmlsec1 for SUSE
